!!! note
    This Class is not meant to be instantiated directly, but rather accessed through the `alm` Property on an
    instance of [Client](client.md). For more details, see the [Guide](alm.md).

::: anaplan_sdk._clients._AlmClient
